
## CATO-CLI - mutation.policy.remotePortFwd.removeSection:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeSection) for documentation on this operation.

### Usage for mutation.policy.remotePortFwd.removeSection:

`catocli mutation policy remotePortFwd removeSection -h`

`catocli mutation policy remotePortFwd removeSection <json>`

`catocli mutation policy remotePortFwd removeSection "$(cat < removeSection.json)"`

`catocli mutation policy remotePortFwd removeSection '{"policyRemoveSectionInput": {"id": {"id": "ID"}}, "remotePortFwdPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}}'`

#### Operation Arguments for mutation.policy.remotePortFwd.removeSection ####
`accountId` [ID] - (required) N/A 
`policyRemoveSectionInput` [PolicyRemoveSectionInput] - (required) N/A 
`remotePortFwdPolicyMutationInput` [RemotePortFwdPolicyMutationInput] - (optional) N/A 
